write_binned_instance_buffers

Function write_binned_instance_buffers 

pub fn write_binned_instance_buffers<BPI, GFBD>(
    views: Query<'_, '_, &ExtractedView>,
    view_binned_render_phases: ResMut<'_, ViewBinnedRenderPhases<BPI>>,
    bin_unpacking_buffers: ResMut<'_, BinUnpackingBuffers>,
    render_device: Res<'_, RenderDevice>,
    render_queue: Res<'_, RenderQueue>,
)
Writes the bin data for each render phase to the GPU.

The bin data consists of the IDs of the mesh instances, as well as the metadata needed for the unpack_bins shader to unpack them.