BatchedInstanceBuffers

Struct BatchedInstanceBuffers 

pub struct BatchedInstanceBuffers<BD, BDI>
where BD: GpuArrayBufferable + Sync + Send + 'static, BDI: AtomicPod,
{ pub current_input_buffer: InstanceInputUniformBuffer<BDI>, pub previous_input_buffer: PreviousInstanceInputUniformBuffer<BDI>, pub phase_instance_buffers: TypeIdMap<UntypedPhaseBatchedInstanceBuffers<BD>>, }
The GPU buffers holding the data needed to render batches.

For example, in the 3D PBR pipeline this holds MeshUniforms, which are the BD type parameter in that mode.

We have a separate buffer data input type (BDI) here, which a compute shader is expected to expand to the full buffer data (BD) type. GPU uniform building is generally faster and uses less system RAM to VRAM bus bandwidth, but only implemented for some pipelines (for example, not in the 2D pipeline at present) and only when compute shader is available.

Fields

current_input_buffer: InstanceInputUniformBuffer<BDI>

The uniform data inputs for the current frame.

These are uploaded during the extraction phase.

previous_input_buffer: PreviousInstanceInputUniformBuffer<BDI>

The uniform data inputs for the previous frame.

The indices don’t generally line up between current_input_buffer and previous_input_buffer, because, among other reasons, entities can spawn or despawn between frames. Instead, each current buffer data input uniform is expected to contain the index of the corresponding buffer data input uniform in this list.

phase_instance_buffers: TypeIdMap<UntypedPhaseBatchedInstanceBuffers<BD>>

The data needed to render buffers for each phase.

The keys of this map are the type IDs of each phase: e.g. Opaque3d, AlphaMask3d, etc.

Implementations

Source

impl<BD, BDI> BatchedInstanceBuffers<BD, BDI>
where BD: GpuArrayBufferable + Sync + Send + 'static, BDI: AtomicPod,

pub fn new() -> Self

Creates new buffers.

pub fn clear(&mut self)

Clears out the buffers in preparation for a new frame.