PreviousInstanceInputUniformBuffer

Struct PreviousInstanceInputUniformBuffer 

pub struct PreviousInstanceInputUniformBuffer<BDI>
where BDI: AtomicPod,
{ /* private fields */ }
Stores the input uniforms for the previous frame.

This doesn’t use a sparse buffer because it’s cleared out every frame and only ever pushed onto. The length is stored in an atomic field, so multiple threads can push simultaneously.

The AtomicRawBufferVec serves as a backing store only. We reserve a large size, enough to hold all push operations that could possibly occur on the worker threads, and only synchronize the changed portion of the buffer to the GPU on each frame.

Implementations

Source

impl<BDI> PreviousInstanceInputUniformBuffer<BDI>
where BDI: AtomicPod,

pub fn new() -> PreviousInstanceInputUniformBuffer<BDI>

Creates a new, empty buffer.

pub fn clear(&mut self)

Clears out the buffer in preparation for a new frame.

pub fn reserve(&mut self, capacity: u32)

Pre-allocates capacity for concurrent Self::push calls.

pub fn push(&self, value: BDI) -> u32

Appends a value and returns its index. Thread-safe.

Self::reserve must have been called first with sufficient capacity.

pub fn ensure_nonempty(&mut self)

Pushes a dummy element onto the backing store of this buffer, if this buffer is empty.

pub fn buffer(&self) -> Option<&Buffer>

Returns the GPU buffer, if allocated.