pub struct PreviousInstanceInputUniformBuffer<BDI>where
BDI: AtomicPod,{ /* private fields */ }Expand description
Stores the input uniforms for the previous frame.
This doesn’t use a sparse buffer because it’s cleared out every frame and only ever pushed onto. The length is stored in an atomic field, so multiple threads can push simultaneously.
The AtomicRawBufferVec serves as a backing store only. We reserve a
large size, enough to hold all push operations that could possibly occur on
the worker threads, and only synchronize the changed portion of the buffer
to the GPU on each frame.
Implementations
Sourceimpl<BDI> PreviousInstanceInputUniformBuffer<BDI>where
BDI: AtomicPod,
impl<BDI> PreviousInstanceInputUniformBuffer<BDI>where
BDI: AtomicPod,
Sourcepub fn new() -> PreviousInstanceInputUniformBuffer<BDI>
pub fn new() -> PreviousInstanceInputUniformBuffer<BDI>
Creates a new, empty buffer.
Sourcepub fn reserve(&mut self, capacity: u32)
pub fn reserve(&mut self, capacity: u32)
Pre-allocates capacity for concurrent Self::push calls.
Sourcepub fn push(&self, value: BDI) -> u32
pub fn push(&self, value: BDI) -> u32
Appends a value and returns its index. Thread-safe.
Self::reserve must have been called first with sufficient capacity.
Sourcepub fn ensure_nonempty(&mut self)
pub fn ensure_nonempty(&mut self)
Pushes a dummy element onto the backing store of this buffer, if this buffer is empty.